# lestpy

## Overview
### Why
Lestpy is aimed to model regression problems with a bunch of logical interactions. This approach is an alternative way to describe the relationship between the features and the targets.

### List of modules
* lbm_model
* visualize
* outlier

## Getting Started
### Installation

You can install LestPy from [PyPI]():

```sh
    python -m pip install lestpy
```

### How to

## Use
Lestpy is designed to be used similarly to sklearn modelization classes and their methods (fit(), transform(), predict(), ...)

## Contributing
There are many ways to support the development of lestpy:

* **File an issue** on Github, if you encounter problems, have a proposal, etc.
* **Send an email with ideas** to the author.
* **Submit a pull request** on Github if you improved the code and know how to use git.


## Links
The source code and issue tracker of this package is to be found on **Github**: [pyonysos/lestpy].


[pyonysos/lestpy]: https://github.com/pyonysos/lestpy